@@ -34,16 +34,17 @@ horizontalcall::horizontalcall(QWidget *parent) :
     if (m_AutorotationEnabled)
     {
         qDebug() << "Main Thread : Init : Autorotation is set to automatic";
-        rotator = new QtMaemo5Rotator(QtMaemo5Rotator::AutomaticBehavior, this);
+        setAttribute(Qt::WA_Maemo5AutoOrientation);
     }
     else
     {
         if (m_Landscape) {
             qDebug() << "Main Thread : I am in landscape mode";
-            rotator = new QtMaemo5Rotator(QtMaemo5Rotator::LandscapeBehavior, this);
+            setAttribute(Qt::WA_Maemo5LandscapeOrientation);
+
         } else {
             qDebug() << "Main Thread : I am in portrait mode";
-            rotator = new QtMaemo5Rotator(QtMaemo5Rotator::PortraitBehavior, this);
+            setAttribute(Qt::WA_Maemo5AutoOrientation);
         }
     }
 
@@ -105,15 +106,15 @@ void horizontalcall::doAction1()
         m_AutorotationEnabled = false;
         settings.setValue("AutoRotation", false);
         if (m_Landscape) {
-            rotator->setCurrentBehavior(QtMaemo5Rotator::LandscapeBehavior);
+            setAttribute(Qt::WA_Maemo5LandscapeOrientation);
         } else {
-            rotator->setCurrentBehavior(QtMaemo5Rotator::PortraitBehavior);
+            setAttribute(Qt::WA_Maemo5PortraitOrientation);
         }
     } else {
         QMaemo5InformationBox::information(this, "AutoRotation is now <b>Enabled</b>", QMaemo5InformationBox::DefaultTimeout);
         m_AutorotationEnabled = true;
         settings.setValue("AutoRotation", true);
-        rotator->setCurrentBehavior(QtMaemo5Rotator::AutomaticBehavior);
+        setAttribute(Qt::WA_Maemo5AutoOrientation);
     }
 }
 
@@ -124,19 +125,19 @@ void horizontalcall::doAction2()
     if (m_AutorotationEnabled) {
         m_AutorotationEnabled = false;
         settings.setValue("AutoRotation", false);
-        rotator->setCurrentBehavior(QtMaemo5Rotator::AutomaticBehavior);
+        setAttribute(Qt::WA_Maemo5AutoOrientation);
     }
     if (m_Landscape) {
         qDebug() << "Main Thread : Switching from landscape to portrait, manual.";
         settings.setValue("ManualRotationLandscape", false);
         QMaemo5InformationBox::information(this, "Perspective is now : <b>Portrait</b>", QMaemo5InformationBox::DefaultTimeout);
-        rotator->setCurrentBehavior(QtMaemo5Rotator::PortraitBehavior);
+        setAttribute(Qt::WA_Maemo5PortraitOrientation);
     } else {
         qDebug() << "Main Thread : Switching from portrait to landscape, manual.";
         settings.setValue("ManualRotationLandscape", true);
         QMaemo5InformationBox::information(this, "Perspective is now : <b>Landscape</b>", QMaemo5InformationBox::DefaultTimeout);
-        rotator->setCurrentBehavior(QtMaemo5Rotator::LandscapeBehavior);
-    }
+        setAttribute(Qt::WA_Maemo5LandscapeOrientation);
+   }
 }
 
 void horizontalcall::doAction3()
